.. _todo:

TODO
=====

[X] create debian package

[X] create documentation

[X] calculate retransmission times for DISCOVER

[X] create tests

[ ] (WIP) integrate with Network Manager

[ ] listen in several interfaces

[X] create systemd service

[X] create init.d daemon: Won't fix.

[X] limit privileges

[X] include MAC anonymization module: Debian package suggest it.

[X] create apparmor profile

[ ] implement IPv6
